@@ -6,14 +6,14 @@ from django.contrib import messages
 from django.core.exceptions import ImproperlyConfigured
 from django.urls import reverse
 from django.http import HttpResponseRedirect
-from django.utils.encoding import smart_text
+from django.utils.encoding import smart_str
 from django.utils.translation import gettext as _
 
 from filebrowser.templatetags.fb_tags import query_helper
 
 
 def get_path(path, site):
-    converted_path = smart_text(os.path.join(site.directory, path))
+    converted_path = smart_str(os.path.join(site.directory, path))
     if not path.startswith('.') and not os.path.isabs(converted_path):
         if site.storage.isdir(converted_path):
             return path
@@ -21,7 +21,7 @@ def get_path(path, site):
 
 def get_file(path, filename, site):
     # Files and directories are valid
-    converted_path = smart_text(os.path.join(site.directory, path, filename))
+    converted_path = smart_str(os.path.join(site.directory, path, filename))
     if not path.startswith('.') and not filename.startswith('.') and not os.path.isabs(converted_path):
         if site.storage.isfile(converted_path) or site.storage.isdir(converted_path):
             return filename
