@@ -5,7 +5,7 @@ import shutil
 from time import sleep
 
 from django.core.files.move import file_move_safe
-from django.utils.encoding import smart_text
+from django.utils.encoding import smart_str
 
 from filebrowser.base import FileObject
 from filebrowser.settings import DEFAULT_PERMISSIONS
@@ -73,7 +73,7 @@ class FileSystemStorageMixin(StorageMixin):
         shutil.rmtree(self.path(name))
 
     def setpermission(self, name):
-        full_path = FileObject(smart_text(name), site=self).path_full
+        full_path = FileObject(smart_str(name), site=self).path_full
         os.chmod(full_path, DEFAULT_PERMISSIONS)
 
 
